@@ -2,23 +2,24 @@
 // This code is governed by the BSD license found in the LICENSE file.
 
 /*---
-es5id: 15.3.5.4_2-57gs
+es5id: 15.3.5.4_2-23gs
 description: >
     Strict mode - checking access to strict function caller from
-    non-strict function (strict function declaration called by
-    non-strict eval)
-flags: [noStrict]
+    strict function (Anonymous FunctionExpression defined within a
+    FunctionDeclaration inside strict mode)
+flags: [onlyStrict]
 ---*/
 
-function f() {
-  "use strict";
-  gNonStrict();
-};
+function f1() {
+  (function() {
+    gNonStrict();
+  })();
+}
 
 assert.throws(TypeError, function() {
-  eval("f();");
+  f1();
 });
 
 function gNonStrict() {
-  return gNonStrict.caller || gNonStrict.caller.throwTypeError;
+  return gNonStrict.caller;
 }
